# -------------------------------------------------------------------------------
# CORRECTION
# Objectif : afficher sur un afficheur graphique la température, l'humidité
# et la pression mesurées par un capteur BME280 .
# Date : 19/6/2023
# Matériels : Raspberry Pi Pico, Shield Grove, capteur BM280, afficheur à SSD1306
# Langage : MicroPython
# IDE : Thonny
# Source : affbme280corr.py,
# Bibliothèque(s) :  /lib/ssd1306.mpy, /lib/bme280.py
# -------------------------------------------------------------------------------
from machine import Pin, I2C
from time import sleep
import bme280  # code de la bibliothèque à placer dans un dossier /lib sur le RP2
import ssd1306  # idem

# BUS I2C0
i2c0 = I2C(0, sda=Pin(8), scl=Pin(9), freq=400_000)

# Afficheur oled (ssd1306) connecté au bus I2C0
oled_width = 128  # px
oled_height = 64  # px
oled = ssd1306.SSD1306_I2C(128, 64, i2c0)

# Capteur BME280 connecté à I2C1 du shield Grove
i2c = I2C(1, scl=Pin(7), sda=Pin(6), freq=400_000)

# Connexion du capteur au bus I2C
bme = bme280.BME280(i2c=i2c)

while True:
    temp = bme.temperature
    hum = bme.humidity
    pres = bme.pressure
    oled.fill(0)
    oled.text("BME280", 15, 0)
    oled.text(f"T = {temp}", 0, 10)
    oled.text(f"H = {hum}", 0, 20)
    oled.text(f"P = {pres}", 0, 30)
    oled.show()
    sleep(5)
