# -------------------------------------------------------------------------------
# CORRECTION
# Objectif: afficher la température délivrée par le capteur interne au
# microcontrôleur sur un afficheur graphique.
# Date : 20/6/2023
# Matériels : Raspberry Pi Pico, Shield Grove, afficheur à SSD1306
# Langage : MicroPython
# IDE : Thonny
# Source : afftempcorr.py
# Bibliothèque(s) : /lib/ssd1306.mpy
# -------------------------------------------------------------------------------
from machine import Pin, I2C
import ssd1306  # code de la bibliothèque à placer dans un dossier /lib sur le RP2
import utime

# BUS I2C0
i2c = I2C(0, sda=Pin(8), scl=Pin(9), freq=400_000)

# Afficheur oled (ssd1306) connecté au bus I2C0
oled_width = 128  # px
oled_height = 64  # px
oled = ssd1306.SSD1306_I2C(128, 64, i2c)

# 1er Affichage
oled.text("Mesure temp.", 5, 0)
oled.show()

# Capteur de température interne au circuit RP2040
sensor_temp = machine.ADC(4)
conversion_factor = 3.3 / (65536)

while True:
    reading = sensor_temp.read_u16() * conversion_factor
    # Le capteur de température mesure la tension Vbe d'une diode bipolaire polarisée, connectée au cinquième ADC
    # Typiquement, Vbe = 0.706V à 27°C, avec une pente de -1.721mV (0.001721) par degré.
    temperature = round(27 - (reading - 0.706)/0.001721, 1)
    print(f"T={temperature}°C")
    oled.fill(0)  # On efface l'écran
    oled.text("Mesure temp.", 5, 0)
    oled.text(f"T={temperature}C", 0, 10)
    oled.show()
    utime.sleep(2)
